﻿local addonName = ...

--[[
Baggins_AucItemSuggest, Adds Auctioneer Item Suggest filters to Baggins ("disenchant", "vendor", etc)

This addon is placed in the public domain.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

]]

local strlower=string.lower
local strmatch=string.match
local GetContainerItemLink, GetContainerItemInfo = GetContainerItemLink, GetContainerItemInfo
local AucAdvanced = AucAdvanced
local Baggins = Baggins
local _G = _G

local dewdrop = AceLibrary and AceLibrary:HasInstance("Dewdrop-2.0") and AceLibrary("Dewdrop-2.0")

local function Rule_Matches(bag,slot,rule)

	local link = GetContainerItemLink(bag, slot)
	if(not link) then return; end
	local _,itemCount = GetContainerItemInfo(bag,slot)

	local suggestion = AucAdvanced and AucAdvanced.Modules.Util.ItemSuggest.itemsuggest(link, itemCount)

	if not suggestion or suggestion=="" then
		return false
	end

	suggestion=strlower(suggestion)
	
	local test = rule.test
	
	if suggestion==test then
		return true
	end

	if test=="any" then
		return true
	end
	
	return false
end

local function Rule_GetName(rule)
	return "ItemSuggest:"..(rule.test or "???")
end


local function Rule_Clean(rule)
	rule.test = "any";
end

local Rule_DewDropOptions = dewdrop and function(rule, level, value)
	if(level == 1) then
		dewdrop:AddLine("text", "Auc-ItemSuggest Options", "isTitle", true);

		dewdrop:AddLine("text", "ItemSuggest: Auction", "checked", rule.test == "auction",
			"func",function(k) rule.test = "auction"; Baggins:OnRuleChanged() end);

		dewdrop:AddLine("text", "ItemSuggest: Vendor", "checked", rule.test == "vendor",
			"func",function(k) rule.test = "vendor"; Baggins:OnRuleChanged() end);

		dewdrop:AddLine("text", "ItemSuggest: Disenchant", "checked", rule.test == "disenchant",
			"func",function(k) rule.test = "disenchant"; Baggins:OnRuleChanged() end);
			
		dewdrop:AddLine("text", "ItemSuggest: Prospect", "checked", rule.test == "prospect",
			"func",function(k) rule.test = "prospect"; Baggins:OnRuleChanged() end);
			
		dewdrop:AddLine("text", "ItemSuggest: Mill", "checked", rule.test == "mill",
			"func",function(k) rule.test = "mill"; Baggins:OnRuleChanged() end);
			
		dewdrop:AddLine("text", "ItemSuggest: Convert", "checked", rule.test == "convert",
			"func",function(k) rule.test = "convert"; Baggins:OnRuleChanged() end);

		dewdrop:AddLine("text", "ItemSuggest: Unknown", "checked", rule.test == "unknown",
			"func",function(k) rule.test = "unknown"; Baggins:OnRuleChanged() end);
			
		dewdrop:AddLine("text", "ItemSuggest: Any", "checked", rule.test == "any",
			"func",function(k) rule.test = "any"; Baggins:OnRuleChanged() end);
	end
end

local Rule_Ace3Options = {
	auction = {
		type="toggle",
		name = "ItemSuggest: Auction",
		get = function(info) return info.arg.test == "auction" end,
		set = function(info) info.arg.test = "auction"; Baggins:OnRuleChanged() end,
	},
	
	
	vendor = {
		type = "toggle",
		name = "ItemSuggest: Vendor", 
		get = function(info) return info.arg.test == "vendor" end,
		set = function(info) info.arg.test = "vendor"; Baggins:OnRuleChanged() end,
	},
	

	disenchant = {
		type = "toggle",
		name = "ItemSuggest: Disenchant",
		get = function(info) return info.arg.test == "disenchant" end,
		set = function(info) info.arg.test = "disenchant"; Baggins:OnRuleChanged() end,
	},
	
	prospect = {
		type = "toggle",
		name = "ItemSuggest: Prospect", 
		get = function(info) return info.arg.test == "prospect" end,
		set = function(info) info.arg.test = "prospect"; Baggins:OnRuleChanged() end,
	},
	
	mill = {
		type = "toggle",
		name = "ItemSuggest: Mill", 
		get = function(info) return info.arg.test == "mill" end,
		set = function(info) info.arg.test = "mill"; Baggins:OnRuleChanged() end,
	},
	
	convert = {
		type = "toggle",
		name = "ItemSuggest: Convert", 
		get = function(info) return info.arg.test == "convert" end,
		set = function(info) info.arg.test = "convert"; Baggins:OnRuleChanged() end,
	},
	
	unknown = {
		type = "toggle",
		name = "ItemSuggest: Unknown", 
		get = function(info) return info.arg.test == "unknown" end,
		set = function(info) info.arg.test = "unknown"; Baggins:OnRuleChanged() end,
	},
	
	
	any = {
		type = "toggle",
		name = "ItemSuggest: Any",
		get = function(info) return info.arg.test == "any" end,
		set = function(info) info.arg.test = "any"; Baggins:OnRuleChanged() end,
	},
	
}






local loaded

local frame = CreateFrame("Frame", "Baggins_AucItemSuggest")
frame:Hide()

frame:SetScript("OnUpdate", function()
	Baggins:ForceFullRefresh()
	frame:Hide()
end)

frame:SetScript("OnEvent", function(self, event, arg)
	if arg==addonName then
		Baggins:AddCustomRule("Auc-ItemSuggest", {
			DisplayName = "Auc-ItemSuggest",
			Description = "Filter according to Auctioneer \"ItemSuggest\"",
			Matches = Rule_Matches,
			GetName = Rule_GetName,
			CleanRule = Rule_Clean,
			DewDropOptions = Rule_DewDropOptions,
			Ace3Options = Rule_Ace3Options,
		});
		frame:Show()	-- queue refresh all
		loaded = true
	end
	
	if loaded then
	
		if not AucAdvanced then
			AucAdvanced = _G.AucAdvanced
			if AucAdvanced then
				frame:Show()	-- queue refresh all
			end
		end
		
		
	
	end
	
end)

frame:RegisterEvent("ADDON_LOADED")
